@@ -1,15 +1,16 @@
 package ColorTheme::Test::Static;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
-our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use strict;
 use warnings;
 use parent 'ColorThemeBase::Static::FromStructColors';
+
 use Color::RGB::Util 'rand_rgb_color';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'ColorThemeBase-Static'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our %THEME = (
     v => 2,
     summary => 'A static color theme',
@@ -42,7 +43,7 @@ ColorTheme::Test::Static - A static color theme
 
 =head1 VERSION
 
-This document describes version 0.008 of ColorTheme::Test::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-19.
+This document describes version 0.009 of ColorTheme::Test::Static (from Perl distribution ColorThemeBase-Static), released on 2024-07-17.
 
 =head1 HOMEPAGE
 
@@ -52,6 +53,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/ColorTheme
 
 Source repository is at L<https://github.com/perlancar/perl-ColorThemeBase-Static>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ColorThemeBase-Static>
@@ -60,15 +90,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
