@@ -1,15 +1,15 @@
 package ColorThemeBase::Static::FromStructColors;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
-our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use strict 'subs', 'vars';
 #use warnings;
 
 use parent 'ColorThemeBase::Base';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'ColorThemeBase-Static'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 sub list_items {
     my $self = shift;
 
@@ -52,7 +52,7 @@ ColorThemeBase::Static::FromStructColors - Base class for color theme modules wi
 
 =head1 VERSION
 
-This document describes version 0.008 of ColorThemeBase::Static::FromStructColors (from Perl distribution ColorThemeBase-Static), released on 2020-06-19.
+This document describes version 0.009 of ColorThemeBase::Static::FromStructColors (from Perl distribution ColorThemeBase-Static), released on 2024-07-17.
 
 =head1 DESCRIPTION
 
@@ -71,14 +71,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/ColorTheme
 
 Source repository is at L<https://github.com/perlancar/perl-ColorThemeBase-Static>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ColorThemeBase-Static>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<ColorThemeBase::Static::FromObjectColors>
@@ -87,11 +79,37 @@ L<ColorThemeBase::Static::FromObjectColors>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ColorThemeBase-Static>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
